@@ -86,10 +86,19 @@ static void begin_of_line(enum tof type, struct process * proc)
 static struct function * name2func(char * name)
 {
 	struct function * tmp;
+	const char * str1, * str2;
 
 	tmp = list_of_functions;
 	while(tmp) {
-		if (!strcmp(tmp->name, name)) {
+#if HAVE_LIBIBERTY
+		str1 = opt_C ? my_demangle(tmp->name) : tmp->name;
+		str2 = opt_C ? my_demangle(name) : name;
+#else
+		str1 = tmp->name;
+		str2 = name;
+#endif
+		if (!strcmp(str1, str2)) {
+
 			return tmp;
 		}
 		tmp = tmp->next;
@@ -145,7 +154,7 @@ void output_left(enum tof type, struct process * proc, char * function_name)
 	proc->type_being_displayed = type;
 	begin_of_line(type, proc);
 #if HAVE_LIBIBERTY
-	current_column += fprintf(output, "%s(", my_demangle(function_name));
+	current_column += fprintf(output, "%s(", opt_C ? my_demangle(function_name): function_name);
 #else
 	current_column += fprintf(output, "%s(", function_name);
 #endif
@@ -154,24 +163,24 @@ void output_left(enum tof type, struct process * proc, char * function_name)
 	if (!func) {
 		int i;
 		for(i=0; i<4; i++) {
-			current_column += display_arg(type, proc, i, LT_PT_UNKNOWN);
+			current_column += display_arg(type, proc, i, ARGTYPE_UNKNOWN);
 			current_column += fprintf(output, ", ");
 		}
-		current_column += display_arg(type, proc, 4, LT_PT_UNKNOWN);
+		current_column += display_arg(type, proc, 4, ARGTYPE_UNKNOWN);
 		return;
 	} else {
 		int i;
 		for(i=0; i< func->num_params - func->params_right - 1; i++) {
-			current_column += display_arg(type, proc, i, func->param_types[i]);
+			current_column += display_arg(type, proc, i, func->arg_types[i]);
 			current_column += fprintf(output, ", ");
 		}
 		if (func->num_params>func->params_right) {
-			current_column += display_arg(type, proc, i, func->param_types[i]);
+			current_column += display_arg(type, proc, i, func->arg_types[i]);
 			if (func->params_right) {
 				current_column += fprintf(output, ", ");
 			}
 		}
-		if (!func->params_right && func->return_type == LT_PT_VOID) {
+		if (!func->params_right && func->return_type == ARGTYPE_VOID) {
 			current_column += fprintf(output, ") ");
 			tabto(opt_a);
 			fprintf(output, "= <void>\n");
@@ -185,38 +194,41 @@ void output_right(enum tof type, struct process * proc, char * function_name)
 {
 	struct function * func = name2func(function_name);
 
-	if (func && func->params_right==0 && func->return_type == LT_PT_VOID) {
+	if (func && func->params_right==0 && func->return_type == ARGTYPE_VOID) {
 		return;
 	}
 
 	if (current_pid && current_pid!=proc->pid) {
 		fprintf(output, " <unfinished ...>\n");
+	}
+	if (current_pid != proc->pid) {
 		begin_of_line(type, proc);
+#if HAVE_LIBIBERTY
+		current_column += fprintf(output, "<... %s resumed> ", opt_C ? my_demangle(function_name) : function_name);
+#else
 		current_column += fprintf(output, "<... %s resumed> ", function_name);
-	} else if (!current_pid) {
-		begin_of_line(type, proc);
-		current_column += fprintf(output, "<... %s resumed> ", function_name);
+#endif
 	}
 
 	if (!func) {
 		current_column += fprintf(output, ") ");
 		tabto(opt_a);
 		fprintf(output, "= ");
-		display_arg(type, proc, -1, LT_PT_UNKNOWN);
+		display_arg(type, proc, -1, ARGTYPE_UNKNOWN);
 		fprintf(output, "\n");
 	} else {
 		int i;
 		for(i=func->num_params-func->params_right; i<func->num_params-1; i++) {
-			current_column += display_arg(type, proc, i, func->param_types[i]);
+			current_column += display_arg(type, proc, i, func->arg_types[i]);
 			current_column += fprintf(output, ", ");
 		}
 		if (func->params_right) {
-			current_column += display_arg(type, proc, i, func->param_types[i]);
+			current_column += display_arg(type, proc, i, func->arg_types[i]);
 		}
 		current_column += fprintf(output, ") ");
 			tabto(opt_a);
 			fprintf(output, "= ");
-		if (func->return_type == LT_PT_VOID) {
+		if (func->return_type == ARGTYPE_VOID) {
 			fprintf(output, "<void>");
 		} else {
 			display_arg(type, proc, -1, func->return_type);
